@@ -1,20 +1,16 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
-
-__all__ = ['Operation', 'RoutingStep']
+from trytond.pool import Pool, PoolMeta
 
 
-class Operation:
-    __metaclass__ = PoolMeta
+class Operation(metaclass=PoolMeta):
     __name__ = 'production.routing.operation'
     work_center_category = fields.Many2One('production.work.center.category',
         'Work Center Category')
 
 
-class RoutingStep:
-    __metaclass__ = PoolMeta
+class RoutingStep(metaclass=PoolMeta):
     __name__ = 'production.routing.step'
 
     def get_work(self, production, work_center_picker):
